pub trait IntoValidatorData {
// Required method
fn into_value(self) -> Value;
}Expand description
Trait for types that can be converted to validator data.
pub trait IntoValidatorData {
// Required method
fn into_value(self) -> Value;
}Trait for types that can be converted to validator data.