pub struct HttpTransport { /* private fields */ }Implementations
Sourceimpl HttpTransport
impl HttpTransport
Sourcepub fn new(
manifest: &ProtocolManifest,
model: &str,
) -> Result<HttpTransport, Error>
pub fn new( manifest: &ProtocolManifest, model: &str, ) -> Result<HttpTransport, Error>
Create a new HttpTransport from a manifest.
If base_url_override is provided, it will be used instead of the manifest’s base_url.
This is useful for testing with mock servers.
Sourcepub fn new_with_base_url(
manifest: &ProtocolManifest,
model: &str,
base_url_override: Option<&str>,
) -> Result<HttpTransport, Error>
pub fn new_with_base_url( manifest: &ProtocolManifest, model: &str, base_url_override: Option<&str>, ) -> Result<HttpTransport, Error>
Create a new HttpTransport with an optional base_url override.
This is primarily for testing, allowing injection of mock server URLs.
pub async fn execute_stream_response( &self, method: &str, path: &str, request_body: &Value, client_request_id: Option<&str>, ) -> Result<Response, Error>
pub async fn execute_stream<'a>( &'a self, method: &str, path: &str, request_body: &Value, ) -> Result<Pin<Box<dyn Stream<Item = Result<Bytes, Error>> + Send + 'a>>, Error>
pub async fn execute_get(&self, path: &str) -> Result<Value, Error>
pub async fn execute_service( &self, path: &str, method: &str, headers: Option<&HashMap<String, String>>, query_params: Option<&HashMap<String, String>>, ) -> Result<Value, Error>