Module utils

Module utils 

Utility modules

Modules

json_path
JSONPath evaluator and path mapper for frame selection and field extraction
tool_call_assembler

Structs

JsonPathEvaluator
JSONPath evaluator for condition matching Supports: exists, ==, !=, in, &&, ||, >, <, >=, <=, regex
PathMapper
Path mapper for extracting and setting values in JSON using dot-notation paths