Error

Enum Error 

pub enum Error {
    Protocol(ProtocolError),
    Pipeline(PipelineError),
    Configuration {
        message: String,
        context: ErrorContext,
    },
    Validation {
        message: String,
        context: ErrorContext,
    },
    Runtime {
        message: String,
        context: ErrorContext,
    },
    Transport(TransportError),
    Io(Error),
    Serialization(Error),
    Remote {
        status: u16,
        class: String,
        message: String,
        retryable: bool,
        fallbackable: bool,
        retry_after_ms: Option<u32>,
        context: Option<ErrorContext>,
    },
    Unknown {
        message: String,
        context: ErrorContext,
    },
}
Unified error type for the AI-Protocol Runtime This aggregates all low-level errors into actionable, high-level categories

Variants



Protocol(ProtocolError)



Pipeline(PipelineError)



Configuration

Fields

message: String


Validation

Fields

message: String


Runtime

Fields

message: String


Transport(TransportError)



Io(Error)



Serialization(Error)



Remote

Fields

status: u16
class: String
message: String
retryable: bool
fallbackable: bool
retry_after_ms: Option<u32>


Unknown

Fields

message: String

Implementations

Source

impl Error

pub fn runtime_with_context( msg: impl Into<String>, context: ErrorContext, ) -> Self

Create a new runtime error with structured context

pub fn validation_with_context( msg: impl Into<String>, context: ErrorContext, ) -> Self

Create a new validation error with structured context

pub fn configuration_with_context( msg: impl Into<String>, context: ErrorContext, ) -> Self

Create a new configuration error with structured context

pub fn unknown_with_context( msg: impl Into<String>, context: ErrorContext, ) -> Self

Create a new unknown error with structured context

pub fn validation(msg: impl Into<String>) -> Self

Create a simple validation error

pub fn configuration(msg: impl Into<String>) -> Self

Create a simple configuration error

pub fn network_with_context( msg: impl Into<String>, context: ErrorContext, ) -> Self

Create a network error with context

pub fn api_with_context(msg: impl Into<String>, context: ErrorContext) -> Self

Create an API error with context

pub fn parsing(msg: impl Into<String>) -> Self

Create a parsing error

pub fn context(&self) -> Option<&ErrorContext>

Extract error context if available

pub fn is_retryable(&self) -> bool

Returns whether this error is retryable.

Checks Remote.retryable, context.retryable, and standard_code().retryable() in order of precedence.

pub fn retry_after(&self) -> Option<Duration>

Returns the suggested retry delay when available.

For Remote errors, converts retry_after_ms to Duration.

pub fn error_code(&self) -> Option<StandardErrorCode>

Returns the AI-Protocol V2 standard error code when available.

Alias for standard_code for convenience.

pub fn standard_code(&self) -> Option<StandardErrorCode>

Returns the AI-Protocol V2 standard error code when available.

For Remote errors, derives the code from the error class if not set in context. Other variants return the standard code from their ErrorContext when present.

pub fn with_context(self, new_ctx: ErrorContext) -> Self

Attach or update context to the error